#' Herleitung der Nutzungseignungsklassen (NEK) nach der NEK-Methode Version 2023
#'
#' Mit der NEK werden Standorte hinsichtlich ihrer landwirtschaftlichen Nutzungseignung beurteilt.
#' Dabei werden Boden, Klima und Terrain berücksichtigt.
#' Dieses Beurteilungsschema wurde hier publiziert:
#'
#' Greiner, L.; Petter, G.; Keller, A. (2023): Anleitung zur Beurteilung der
#' landwirtschaftlichen Nutzungseignung. Methode der Nutzungseignungsklassen (NEK-Methode).
#' Aktualisierte Version 2023. Kompetenzzentrum Boden KOBO. BFH-HAFL.
#'
#'
#' Die hier vorliegende Beurteilung basiert
#' auf den Bewertungstabellen der NEK-2023 Stand 24.10.2023
#'
#'
#'
#' @param eingangsdaten_nek2023 Enthält folgende Daten: nabodat_standortid,x_koord,y_koord,klimaeignungszone,whug,ob_skelett,ob_ton,ub_ton,ob_Schluff,ub_schluff,ob_humus,ub_humus,ub_ph,hangneigung,gelaendeform (siehe die NABODATv5.1. Beispieldaten "eingangsdaten_nek2023" --> data/eingangsdaten_nek2023)
#' @return data.frame mit allen Eingangsdaten, den einzelnen Limitierungen, der schlussendlichen NEK-2023 und die schlussendliche(n) Limitierung(en)
#' @export


nek_2023<- function(eingangsdaten_nek2023){

  ## Bewertungstabellen NEK 2023 laden
  data("bewertungstabellen_nek2023")

  ## Eingangsdaten unterteilen ------
  p1_standortid <- eingangsdaten_nek2023$nabodat_standortid
  x_koord       <- eingangsdaten_nek2023$x_koord
  y_koord       <- eingangsdaten_nek2023$y_koord
  klimaeignungszone<- eingangsdaten_nek2023$klimaeignungszone
  whug<- eingangsdaten_nek2023$whug
  ob_skelett<- eingangsdaten_nek2023$ob_skelett
  ob_ton<- eingangsdaten_nek2023$ob_ton
  ub_ton<- eingangsdaten_nek2023$ub_ton
  ob_schluff<- eingangsdaten_nek2023$ob_schluff
  ub_schluff<- eingangsdaten_nek2023$ub_schluff
  ob_humus<- eingangsdaten_nek2023$ob_humus
  ub_humus<- eingangsdaten_nek2023$ub_humus
  ub_ph<- eingangsdaten_nek2023$ub_ph
  hangneigung <- eingangsdaten_nek2023$hangneigung
  gelaendeform<- eingangsdaten_nek2023$gelaendeform



  ## Bewertungstabelle unterteilen ------
  bewertungstab_whg   <-  data.frame(bewertungstabellen_nek2023[[1]]) # Teil Wasserhaushaltgruppe
  bewertungstab_stein <-  data.frame(bewertungstabellen_nek2023[[2]]) # Teil Steingehalt Oberboden
  bewertungstab_textur<-  data.frame(bewertungstabellen_nek2023[[3]]) # Teil Textur Oberboden
  bewertungstab_humus <-  data.frame(bewertungstabellen_nek2023[[4]]) # Teil Humusgehalt Oberboden
  bewertungstab_pH    <-  data.frame(bewertungstabellen_nek2023[[5]]) # Teil Säuregrad Oberboden
  bewertungstab_terrain  <-  data.frame(bewertungstabellen_nek2023[[6]]) # Teil Geländeform
  bewertungstab_spez1 <- data.frame(bewertungstabellen_nek2023[[7]]) # Teil Geländeform, Gefügestabilität, WHG, Textur
  bewertungstab_spez2 <- data.frame(bewertungstabellen_nek2023[[8]]) # Teil Geländeform, Gefügestabilität, WHG, Textur
  nutzungsgebietzuordnung <- data.frame(bewertungstabellen_nek2023[[9]]) # Teil Geländeform, Gefügestabilität, WHG, Textur


  ## Vorarbeit: Nutzungsgebiet zuordnen-------
  klimalim <- ng_aus_klimaek(klimaeignungszone,nutzungsgebietzuordnung)



  ## Vorarbeit: Neigungsart unregelmässig
  neigungsart_unregelmaessig <- stringr::str_detect(gelaendeform,"n")


  # NEK-WHG---------------------------------------
  nek_whg2023 <- nek_whg(whug, klimalim,bewertungstab_whg)

  # NEK-Skelett-------------------------------------
  nek_skelett2023  <- nek_skelett(ob_skelett, klimalim, bewertungstab_stein)

  # NEK-Textur-------------------------------------
  nek_textur2023 <- nek_textur(ob_ton, ob_schluff,klimalim, bewertungstab_textur)

  # NEK-Humus--------------------------------------
  nek_humus2023 <- nek_humus(ob_humus, ub_humus, klimalim,bewertungstab_humus)

  # NEK-pH-----------------------------------------
  nek_ph2023 <- nek_ph(ub_ph,klimalim,bewertungstab_pH)

  # NEK-terrain---------------------------------------
  nek_terrain2023 <- nek_terrain(hangneigung,neigungsart_unregelmaessig, klimalim,bewertungstab_terrain)

  # NEK-Spezialfälle----------------------------------
  nek_spezialfaelle2023 <- nek_spezialfaelle(hangneigung,whug, neigungsart_unregelmaessig,
                                             ub_ton, ub_schluff,klimalim,bewertungstab_spez1,bewertungstab_spez2)

  #GesamtNEK-----------------------
  alle_neks  <- data.frame(nek_whg2023, nek_skelett2023, nek_textur2023, nek_humus2023,
                           nek_ph2023, nek_terrain2023, nek_spezialfaelle2023)

  resultate           <- gesamtnek_2023(alle_neks)
  nek2023             <- resultate$nek_bokazh
  nek2023_limitierung <- resultate$limitierung

  alles <- cbind(eingangsdaten_nek2023, alle_neks, resultate)

  return(alles)


}







